timerelationtools.timespan_2_starts_before_timespan_1_stops
===========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_starts_before_timespan_1_stops.timespan_2_starts_before_timespan_1_stops
   :noindex:
